summaryrefslogtreecommitdiffstats
path: root/nsplugins
diff options
context:
space:
mode:
Diffstat (limited to 'nsplugins')
-rw-r--r--nsplugins/kcm_nsplugins.cpp4
-rw-r--r--nsplugins/nspluginloader.cpp14
-rw-r--r--nsplugins/plugin_part.cpp2
-rw-r--r--nsplugins/pluginscan.cpp12
-rw-r--r--nsplugins/sdk/jni_md.h30
-rw-r--r--nsplugins/sdk/jri_md.h47
-rw-r--r--nsplugins/sdk/npapi.h16
-rw-r--r--nsplugins/sdk/obsolete/protypes.h14
-rw-r--r--nsplugins/sdk/prcpucfg.h46
-rw-r--r--nsplugins/sdk/prtypes.h6
-rw-r--r--nsplugins/test/testnsplugin.cpp2
-rw-r--r--nsplugins/viewer/CMakeLists.txt2
-rw-r--r--nsplugins/viewer/nsplugin.cpp16
-rw-r--r--nsplugins/viewer/qxteventloop.cpp18
-rw-r--r--nsplugins/viewer/viewer.cpp8
-rw-r--r--nsplugins/wrapper/wrapper.c30
16 files changed, 97 insertions, 170 deletions
diff --git a/nsplugins/kcm_nsplugins.cpp b/nsplugins/kcm_nsplugins.cpp
index c60a7acbe..c394afa8f 100644
--- a/nsplugins/kcm_nsplugins.cpp
+++ b/nsplugins/kcm_nsplugins.cpp
@@ -22,7 +22,7 @@
#include <tqregexp.h>
#include <tqlayout.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdelocale.h>
#include <kiconloader.h>
#include <tdefiledialog.h>
@@ -34,7 +34,7 @@
#include <tdeapplication.h>
#include <dcopclient.h>
-#include <kprocio.h>
+#include <tdeprocio.h>
#include "plugin_paths.h"
diff --git a/nsplugins/plugin_part.cpp b/nsplugins/plugin_part.cpp
index 3e5530f3a..500361464 100644
--- a/nsplugins/plugin_part.cpp
+++ b/nsplugins/plugin_part.cpp
@@ -301,7 +301,7 @@ bool PluginPart::openURL(const KURL &url)
emit setStatusBarText( i18n("Loading Netscape plugin for %1").arg(url.prettyURL()) );
// create plugin widget
- NSPluginInstance *inst = _loader->newInstance(_canvas, surl, smime, embed, argn, argv, kapp->dcopClient()->appId(), _callback->objId(), reload, post, _extension->urlArgs().postData);
+ NSPluginInstance *inst = _loader->newInstance(_canvas, surl, smime, embed, argn, argv, tdeApp->dcopClient()->appId(), _callback->objId(), reload, post, _extension->urlArgs().postData);
if ( inst ) {
_widget = inst;
diff --git a/nsplugins/pluginscan.cpp b/nsplugins/pluginscan.cpp
index 8e08178be..8ea6b1ffb 100644
--- a/nsplugins/pluginscan.cpp
+++ b/nsplugins/pluginscan.cpp
@@ -43,11 +43,11 @@
#include <tdeapplication.h>
#include <kdebug.h>
#include <tdeglobal.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <klibloader.h>
#include <tdeconfig.h>
-#include <kcrash.h>
-#include <kdesktopfile.h>
+#include <tdecrash.h>
+#include <tdedesktopfile.h>
#include <kservicetype.h>
#include <kmimetype.h>
#include <tdecmdlineargs.h>
@@ -112,7 +112,7 @@ TDEConfig *infoConfig = 0;
bool isPluginMimeType( TQString fname )
{
- KDesktopFile cfg( fname, true );
+ TDEDesktopFile cfg( fname, true );
cfg.setDesktopGroup();
return cfg.hasKey( "X-TDE-nsplugin" );
}
@@ -415,7 +415,7 @@ void scanDirectory( TQString dir, TQStringList &mimeInfoList,
}
// write into type cache
- TQStringList tokens = TQStringList::split(':', *type, TRUE);
+ TQStringList tokens = TQStringList::split(':', *type, true);
TQStringList::Iterator token;
token = tokens.begin();
cache << (*token).lower();
@@ -653,7 +653,7 @@ int main( int argc, char **argv )
printf("90\n"); fflush(stdout);
}
- DCOPClient *dcc = kapp->dcopClient();
+ DCOPClient *dcc = tdeApp->dcopClient();
if ( !dcc->isAttached() )
dcc->attach();
// Tel kded to update sycoca database.
diff --git a/nsplugins/sdk/jni_md.h b/nsplugins/sdk/jni_md.h
index 58738bbd0..6ab327cd3 100644
--- a/nsplugins/sdk/jni_md.h
+++ b/nsplugins/sdk/jni_md.h
@@ -63,9 +63,9 @@
* WHAT'S UP WITH THIS FILE?
*
* This is where we define the mystical JNI_PUBLIC_API macro that works on all
- * platforms. If you're running with Visual C++, Symantec C, or Borland's
+ * platforms. If you're running with Visual C++ or Symantec C
* development environment on the PC, you're all set. Or if you're on the Mac
- * with Metrowerks, Symantec or MPW with SC you're ok too. For UNIX it shouldn't
+ * with Symantec or MPW with SC you're ok too. For UNIX it shouldn't
* matter.
* Changes by sailesh on 9/26
@@ -132,18 +132,6 @@
# define JNICALL __export
# endif /* !WINDLL */
# endif /* !_WIN32 */
-# elif defined(__BORLANDC__)
-# if defined(WIN32) || defined(_WIN32)
-# define JNI_PUBLIC_API(ResultType) __export ResultType
-# define JNI_PUBLIC_VAR(VarType) VarType
-# define JNI_NATIVE_STUB(ResultType) __export ResultType
-# define JNICALL
-# else /* !_WIN32 */
-# define JNI_PUBLIC_API(ResultType) ResultType _cdecl _export _loadds
-# define JNI_PUBLIC_VAR(VarType) VarType
-# define JNI_NATIVE_STUB(ResultType) ResultType _cdecl _loadds
-# define JNICALL _loadds
-# endif
# else
# error Unsupported PC development environment.
# endif
@@ -156,19 +144,7 @@
/* Mac */
#elif defined(macintosh) || defined(Macintosh) || defined(THINK_C)
-# if defined(__MWERKS__) /* Metrowerks */
-# if !__option(enumsalwaysint)
-# error You need to define 'Enums Always Int' for your project.
-# endif
-# if defined(TARGET_CPU_68K) && !TARGET_RT_MAC_CFM
-# if !__option(fourbyteints)
-# error You need to define 'Struct Alignment: 68k' for your project.
-# endif
-# endif /* !GENERATINGCFM */
-# define JNI_PUBLIC_API(ResultType) __declspec(export) ResultType
-# define JNI_PUBLIC_VAR(VarType) JNI_PUBLIC_API(VarType)
-# define JNI_NATIVE_STUB(ResultType) JNI_PUBLIC_API(ResultType)
-# elif defined(__SC__) /* Symantec */
+# if defined(__SC__) /* Symantec */
# error What are the Symantec defines? (warren@netscape.com)
# elif macintosh && applec /* MPW */
# error Please upgrade to the latest MPW compiler (SC).
diff --git a/nsplugins/sdk/jri_md.h b/nsplugins/sdk/jri_md.h
index 8234addd4..3faf842dc 100644
--- a/nsplugins/sdk/jri_md.h
+++ b/nsplugins/sdk/jri_md.h
@@ -52,9 +52,9 @@ extern "C" {
* WHAT'S UP WITH THIS FILE?
*
* This is where we define the mystical JRI_PUBLIC_API macro that works on all
- * platforms. If you're running with Visual C++, Symantec C, or Borland's
+ * platforms. If you're running with Visual C++ or Symantec C
* development environment on the PC, you're all set. Or if you're on the Mac
- * with Metrowerks, Symantec or MPW with SC you're ok too. For UNIX it shouldn't
+ * with Symantec or MPW with SC you're ok too. For UNIX it shouldn't
* matter.
*
* On UNIX though you probably care about a couple of other symbols though:
@@ -105,22 +105,6 @@ extern "C" {
# define JRI_CALLBACK __export
# endif /* !WINDLL */
# endif /* !_WIN32 */
-# elif defined(__BORLANDC__)
-# if defined(WIN32) || defined(_WIN32)
-# define JRI_PUBLIC_API(ResultType) __export ResultType
-# define JRI_PUBLIC_VAR(VarType) VarType
-# define JRI_PUBLIC_VAR_EXP(VarType) __export VarType
-# define JRI_PUBLIC_VAR_IMP(VarType) __import VarType
-# define JRI_NATIVE_STUB(ResultType) __export ResultType
-# define JRI_CALLBACK
-# else /* !_WIN32 */
-# define JRI_PUBLIC_API(ResultType) ResultType _cdecl _export _loadds
-# define JRI_PUBLIC_VAR(VarType) VarType
-# define JRI_PUBLIC_VAR_EXP(VarType) __cdecl __export VarType
-# define JRI_PUBLIC_VAR_IMP(VarType) __cdecl __import VarType
-# define JRI_NATIVE_STUB(ResultType) ResultType _cdecl _loadds
-# define JRI_CALLBACK _loadds
-# endif
# else
# error Unsupported PC development environment.
# endif
@@ -130,21 +114,7 @@ extern "C" {
/* Mac */
#elif defined (macintosh) || defined(Macintosh) || defined(THINK_C)
-# if defined(__MWERKS__) /* Metrowerks */
-# if !__option(enumsalwaysint)
-# error You need to define 'Enums Always Int' for your project.
-# endif
-# if defined(TARGET_CPU_68K) && !TARGET_RT_MAC_CFM
-# if !__option(fourbyteints)
-# error You need to define 'Struct Alignment: 68k' for your project.
-# endif
-# endif /* !GENERATINGCFM */
-# define JRI_PUBLIC_API(ResultType) __declspec(export) ResultType
-# define JRI_PUBLIC_VAR(VarType) JRI_PUBLIC_API(VarType)
-# define JRI_PUBLIC_VAR_EXP(VarType) JRI_PUBLIC_API(VarType)
-# define JRI_PUBLIC_VAR_IMP(VarType) JRI_PUBLIC_API(VarType)
-# define JRI_NATIVE_STUB(ResultType) JRI_PUBLIC_API(ResultType)
-# elif defined(__SC__) /* Symantec */
+# if defined(__SC__) /* Symantec */
# error What are the Symantec defines? (warren@netscape.com)
# elif macintosh && applec /* MPW */
# error Please upgrade to the latest MPW compiler (SC).
@@ -208,16 +178,7 @@ typedef long jint;
#ifdef HAVE_LONG_LONG
-#ifdef OSF1
-
-/* long is default 64-bit on OSF1, -std1 does not allow long long */
-typedef long jlong;
-typedef unsigned long julong;
-#define jlong_MAXINT 0x7fffffffffffffffL
-#define jlong_MININT 0x8000000000000000L
-#define jlong_ZERO 0x0L
-
-#elif (defined(WIN32) || defined(_WIN32))
+#if (defined(WIN32) || defined(_WIN32))
typedef LONGLONG jlong;
typedef DWORDLONG julong;
diff --git a/nsplugins/sdk/npapi.h b/nsplugins/sdk/npapi.h
index 18992ae0d..467138946 100644
--- a/nsplugins/sdk/npapi.h
+++ b/nsplugins/sdk/npapi.h
@@ -50,7 +50,6 @@
#include "prtypes.h"
/* Copied from xp_core.h */
-/* removed #ifdef for hpux defined in /usr/include/model.h */
#ifndef XP_MAC
#ifndef _INT16
#define _INT16
@@ -92,21 +91,6 @@
# endif /* XP_WIN */
#endif /* _WINDOWS */
-#ifdef __MWERKS__
-# define _declspec __declspec
-# ifdef macintosh
-# ifndef XP_MAC
-# define XP_MAC 1
-# endif /* XP_MAC */
-# endif /* macintosh */
-# ifdef __INTEL__
-# undef NULL
-# ifndef XP_WIN
-# define XP_WIN 1
-# endif /* XP_WIN */
-# endif /* __INTEL__ */
-#endif /* __MWERKS__ */
-
#if defined(XP_MAC) || defined(XP_MACOSX)
#include <Quickdraw.h>
#include <Events.h>
diff --git a/nsplugins/sdk/obsolete/protypes.h b/nsplugins/sdk/obsolete/protypes.h
index 5d9190aa2..efd2a1509 100644
--- a/nsplugins/sdk/obsolete/protypes.h
+++ b/nsplugins/sdk/obsolete/protypes.h
@@ -82,11 +82,6 @@ typedef PRIntn intn;
#include <sys/types.h>
#endif
-/* model.h on HP-UX defines int8, int16, and int32. */
-#ifdef HPUX
-#include <model.h>
-#endif
-
/*
* uint
*/
@@ -146,8 +141,7 @@ typedef PRInt64 int64;
*/
#if !defined(XP_BEOS) && !defined(VMS) \
- && !defined(_PR_AIX_HAVE_BSD_INT_TYPES) \
- && !defined(HPUX)
+ && !defined(_PR_AIX_HAVE_BSD_INT_TYPES)
#if !defined(WIN32) || !defined(_WINSOCK2API_) /* defines its own "int32" */
#if !defined(XP_MAC) && !defined(_WIN32) && !defined(XP_OS2) && !defined(NTO)
typedef PRInt32 int32;
@@ -162,8 +156,7 @@ typedef long int32;
*/
#if !defined(XP_BEOS) && !defined(VMS) \
- && !defined(_PR_AIX_HAVE_BSD_INT_TYPES) \
- && !defined(HPUX)
+ && !defined(_PR_AIX_HAVE_BSD_INT_TYPES)
typedef PRInt16 int16;
#endif
@@ -172,8 +165,7 @@ typedef PRInt16 int16;
*/
#if !defined(XP_BEOS) && !defined(VMS) \
- && !defined(_PR_AIX_HAVE_BSD_INT_TYPES) \
- && !defined(HPUX)
+ && !defined(_PR_AIX_HAVE_BSD_INT_TYPES)
typedef PRInt8 int8;
#endif
diff --git a/nsplugins/sdk/prcpucfg.h b/nsplugins/sdk/prcpucfg.h
index 71fd9f658..1df6b01f5 100644
--- a/nsplugins/sdk/prcpucfg.h
+++ b/nsplugins/sdk/prcpucfg.h
@@ -741,6 +741,52 @@
#define PR_BYTES_PER_WORD_LOG2 3
#define PR_BYTES_PER_DWORD_LOG2 3
+#elif defined(__loongarch64)
+
+#undef IS_BIG_ENDIAN
+#define IS_LITTLE_ENDIAN 1
+#define IS_64
+
+#define PR_BYTES_PER_BYTE 1
+#define PR_BYTES_PER_SHORT 2
+#define PR_BYTES_PER_INT 4
+#define PR_BYTES_PER_INT64 8
+#define PR_BYTES_PER_LONG 8
+#define PR_BYTES_PER_FLOAT 4
+#define PR_BYTES_PER_DOUBLE 8
+#define PR_BYTES_PER_WORD 8
+#define PR_BYTES_PER_DWORD 8
+
+#define PR_BITS_PER_BYTE 8
+#define PR_BITS_PER_SHORT 16
+#define PR_BITS_PER_INT 32
+#define PR_BITS_PER_INT64 64
+#define PR_BITS_PER_LONG 64
+#define PR_BITS_PER_FLOAT 32
+#define PR_BITS_PER_DOUBLE 64
+#define PR_BITS_PER_WORD 64
+
+#define PR_BITS_PER_BYTE_LOG2 3
+#define PR_BITS_PER_SHORT_LOG2 4
+#define PR_BITS_PER_INT_LOG2 5
+#define PR_BITS_PER_INT64_LOG2 6
+#define PR_BITS_PER_LONG_LOG2 6
+#define PR_BITS_PER_FLOAT_LOG2 5
+#define PR_BITS_PER_DOUBLE_LOG2 6
+#define PR_BITS_PER_WORD_LOG2 6
+
+#define PR_ALIGN_OF_SHORT 2
+#define PR_ALIGN_OF_INT 4
+#define PR_ALIGN_OF_LONG 8
+#define PR_ALIGN_OF_INT64 8
+#define PR_ALIGN_OF_FLOAT 4
+#define PR_ALIGN_OF_DOUBLE 8
+#define PR_ALIGN_OF_POINTER 8
+#define PR_ALIGN_OF_WORD 8
+
+#define PR_BYTES_PER_WORD_LOG2 3
+#define PR_BYTES_PER_DWORD_LOG2 3
+
#else
#error "Unknown CPU architecture"
diff --git a/nsplugins/sdk/prtypes.h b/nsplugins/sdk/prtypes.h
index 842013ee8..29bad8018 100644
--- a/nsplugins/sdk/prtypes.h
+++ b/nsplugins/sdk/prtypes.h
@@ -266,10 +266,8 @@ typedef unsigned char PRUint8;
** For these compilers, we have to define PRInt8 as plain 'char'.
** Make sure that plain 'char' is indeed signed under these compilers.
*/
-#if (defined(HPUX) && defined(__cplusplus) \
- && !defined(__GNUC__) && __cplusplus < 199707L) \
- || (defined(SCO) && defined(__cplusplus) \
- && !defined(__GNUC__) && __cplusplus == 1L)
+#if defined(SCO) && defined(__cplusplus) \
+ && !defined(__GNUC__) && __cplusplus == 1L
typedef char PRInt8;
#else
typedef signed char PRInt8;
diff --git a/nsplugins/test/testnsplugin.cpp b/nsplugins/test/testnsplugin.cpp
index 7ac24ee2c..821f17e29 100644
--- a/nsplugins/test/testnsplugin.cpp
+++ b/nsplugins/test/testnsplugin.cpp
@@ -46,7 +46,7 @@ TestNSPlugin::TestNSPlugin()
// file menu
KStdAction::openNew( this, TQ_SLOT(newView()), actionCollection());
KStdAction::close( this, TQ_SLOT(closeView()), actionCollection());
- KStdAction::quit( kapp, TQ_SLOT(quit()), actionCollection());
+ KStdAction::quit( tdeApp, TQ_SLOT(quit()), actionCollection());
createGUI( "testnspluginui.rc" );
}
diff --git a/nsplugins/viewer/CMakeLists.txt b/nsplugins/viewer/CMakeLists.txt
index 08a3778d7..48a71ed80 100644
--- a/nsplugins/viewer/CMakeLists.txt
+++ b/nsplugins/viewer/CMakeLists.txt
@@ -31,6 +31,6 @@ tde_add_executable( nspluginviewer AUTOMOC
../NSPluginCallbackIface.stub NSPluginClassIface.skel
nsplugin.cpp viewer.cpp qxteventloop.cpp
glibevents.cpp
- LINK tdeparts-shared tdeio-shared ${GLIB2_LIBRARIES} Xt ${DL_LIBRARIES}
+ LINK tdeparts-shared tdeio-shared ${GLIB2_LIBRARIES} Xt ${CMAKE_DL_LIBS}
DESTINATION ${BIN_INSTALL_DIR}
)
diff --git a/nsplugins/viewer/nsplugin.cpp b/nsplugins/viewer/nsplugin.cpp
index be5a18f9f..5a873c45d 100644
--- a/nsplugins/viewer/nsplugin.cpp
+++ b/nsplugins/viewer/nsplugin.cpp
@@ -49,9 +49,9 @@
#include <tdeio/netaccess.h>
#include <klibloader.h>
#include <tdelocale.h>
-#include <kprocess.h>
+#include <tdeprocess.h>
#include <tdeprotocolmanager.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdetempfile.h>
#include <kurl.h>
@@ -1323,7 +1323,7 @@ DCOPRef NSPluginViewer::newClass( TQString plugin )
_classes.insert( plugin, cls );
}
- return DCOPRef( kapp->dcopClient()->appId(), cls->objId() );
+ return DCOPRef( tdeApp->dcopClient()->appId(), cls->objId() );
}
@@ -1566,7 +1566,7 @@ DCOPRef NSPluginClass::newInstance( TQString url, TQString mimeType, TQ_INT8 emb
}
_instances.append( inst );
- return DCOPRef(kapp->dcopClient()->appId(), inst->objId());
+ return DCOPRef(tdeApp->dcopClient()->appId(), inst->objId());
}
@@ -1574,7 +1574,7 @@ void NSPluginClass::destroyInstance( NSPluginInstance* inst )
{
// mark for destruction
_trash.append( inst );
- timer(); //_timer->start( 0, TRUE );
+ timer(); //_timer->start( 0, true );
}
/****************************************************************************/
@@ -1642,7 +1642,7 @@ void NSPluginStreamBase::inform()
// stream into temporary file (use lower() in case the
// filename as an upper case X in it)
_tempFile = new KTempFile;
- _tempFile->setAutoDelete( TRUE );
+ _tempFile->setAutoDelete( true );
_fileURL = _tempFile->name();
kdDebug() << "saving into " << _fileURL << endl;
}
@@ -1949,7 +1949,7 @@ void NSPluginStream::data(TDEIO::Job * job, const TQByteArray &data)
queue( data );
if ( !pump() ) {
_job->suspend();
- _resumeTimer->start( 100, TRUE );
+ _resumeTimer->start( 100, true );
}
}
@@ -1986,7 +1986,7 @@ void NSPluginStream::resume()
_job->resume();
} else {
kdDebug(1431) << "restart timer" << endl;
- _resumeTimer->start( 100, TRUE );
+ _resumeTimer->start( 100, true );
}
}
diff --git a/nsplugins/viewer/qxteventloop.cpp b/nsplugins/viewer/qxteventloop.cpp
index 1f112ba08..b8b4329b2 100644
--- a/nsplugins/viewer/qxteventloop.cpp
+++ b/nsplugins/viewer/qxteventloop.cpp
@@ -93,8 +93,8 @@ bool QXtEventLoop::redeliverEvent( XEvent *event )
{
// redeliver the event to Xt, NOT through Qt
if ( static_d->dispatchers[ event->type ]( event ) )
- return TRUE;
- return FALSE;
+ return true;
+ return false;
}
@@ -108,7 +108,7 @@ XEvent* QXtEventLoop::lastEvent()
QXtEventLoopPrivate::QXtEventLoopPrivate()
: appContext(NULL), ownContext(NULL),
- activate_timers(FALSE), timerid(0)
+ activate_timers(false), timerid(0)
{
}
@@ -181,18 +181,18 @@ Boolean qmotif_event_dispatcher( XEvent *event )
case EnterNotify:
case LeaveNotify:
event->xcrossing.focus = False;
- delivered = FALSE;
+ delivered = false;
break;
case XKeyPress:
case XKeyRelease:
- delivered = TRUE;
+ delivered = true;
break;
case XFocusIn:
case XFocusOut:
- delivered = FALSE;
+ delivered = false;
break;
default:
- delivered = FALSE;
+ delivered = false;
break;
}
}
@@ -412,7 +412,7 @@ void QXtEventLoop::unregisterSocketNotifier( TQSocketNotifier *notifier )
*/
void qmotif_timeout_handler( XtPointer, XtIntervalId * )
{
- static_d->activate_timers = TRUE;
+ static_d->activate_timers = true;
static_d->timerid = 0;
}
@@ -461,7 +461,7 @@ bool QXtEventLoop::processEvents( ProcessEventsFlags flags )
if ( d->activate_timers ) {
nevents += activateTimers();
}
- d->activate_timers = FALSE;
+ d->activate_timers = false;
return ( (flags & WaitForMore) || ( pendingmask != 0 ) || nevents > 0 );
}
diff --git a/nsplugins/viewer/viewer.cpp b/nsplugins/viewer/viewer.cpp
index 6007e5b0e..488168b4d 100644
--- a/nsplugins/viewer/viewer.cpp
+++ b/nsplugins/viewer/viewer.cpp
@@ -152,7 +152,7 @@ bool qt_set_socket_handler( int sockfd, int type, TQObject *obj, bool enable )
#if defined(CHECK_RANGE)
tqWarning( "TQSocketNotifier: Internal error" );
#endif
- return FALSE;
+ return false;
}
XtPointer inpMask = 0;
@@ -161,7 +161,7 @@ bool qt_set_socket_handler( int sockfd, int type, TQObject *obj, bool enable )
case TQSocketNotifier::Read: inpMask = (XtPointer)XtInputReadMask; break;
case TQSocketNotifier::Write: inpMask = (XtPointer)XtInputWriteMask; break;
case TQSocketNotifier::Exception: inpMask = (XtPointer)XtInputExceptMask; break;
- default: return FALSE;
+ default: return false;
}
if (enable) {
@@ -197,13 +197,13 @@ bool qt_set_socket_handler( int sockfd, int type, TQObject *obj, bool enable )
while ( sn && !(sn->obj == obj && sn->fd == sockfd) )
sn = _notifiers[type].next();
if ( !sn ) // not found
- return FALSE;
+ return false;
XtRemoveInput( sn->id );
_notifiers[type].remove();
}
- return TRUE;
+ return true;
}
#endif
diff --git a/nsplugins/wrapper/wrapper.c b/nsplugins/wrapper/wrapper.c
index 965868426..7caf645cb 100644
--- a/nsplugins/wrapper/wrapper.c
+++ b/nsplugins/wrapper/wrapper.c
@@ -4,11 +4,7 @@
#include <X11/Xlib.h>
#include <X11/Xlibint.h>
-#ifdef __hpux
-#include <dl.h>
-#else
#include <dlfcn.h>
-#endif
#define XP_UNIX 1
#include "sdk/npupp.h"
@@ -28,26 +24,13 @@ NP_Initialize_t *gNP_Initialize = NULL;
NP_Shutdown_t *gNP_Shutdown = NULL;
NP_GetValue_t *gNP_GetValue = NULL;
-#ifdef __hpux
-shl_t gLib;
-#else
void *gLib = 0L;
-#endif
FILE *ef = 0L;
#define DEB fprintf
static
void UnloadPlugin() {
-#ifdef __hpux
- if (gLib) {
- DEB( ef, "-> UnloadPlugin\n" );
- shl_unload(gLib);
- DEB( ef, "<- UnloadPlugin\n" );
-
- gLib=0L;
- }
-#else
if ( gLib ) {
DEB( ef, "-> UnloadPlugin\n" );
dlclose( gLib );
@@ -57,7 +40,6 @@ void UnloadPlugin() {
if (ef) fclose( ef );
}
-#endif
}
static
@@ -70,17 +52,6 @@ void LoadPlugin() {
setvbuf( ef, NULL, _IONBF, 0 );
DEB( ef, "-> LoadPlugin\n" );
-#ifdef __hpux
- gLib = shl_load("/tmp/plugin.so", BIND_IMMEDIATE, 0L);
- if (shl_findsym(&gLib, "/tmp/plugin.so", (short) TYPE_PROCEDURE, (void *) &gNP_GetMIMEDescription))
- gNP_GetMIMEDescription = NULL;
- if (shl_findsym(&gLib, "/tmp/plugin.so", (short) TYPE_PROCEDURE, (void *) &gNP_Initialize))
- gNP_Initialize = NULL;
- if (shl_findsym(&gLib, "/tmp/plugin.so", (short) TYPE_PROCEDURE, (void *) &gNP_Shutdown))
- gNP_Shutdown = NULL;
- if (shl_findsym(&gLib, "/tmp/plugin.so", (short) TYPE_PROCEDURE, (void *) &gNP_GetValue))
- gNP_GetValue = NULL;
-#else
gLib = dlopen( "/tmp/plugin.so", RTLD_NOW );
DEB( ef, "gLib = %x\n", gLib );
@@ -88,7 +59,6 @@ void LoadPlugin() {
gNP_Initialize = dlsym( gLib, "NP_Initialize" );
gNP_Shutdown = dlsym( gLib, "NP_Shutdown" );
gNP_GetValue = dlsym( gLib, "NP_GetValue" );
-#endif
DEB( ef, "gNP_GetMIMEDescription = %x\n", NP_GetMIMEDescription );
DEB( ef, "gNP_Initialize = %x\n", gNP_Initialize );
DEB( ef, "gNP_Shutdown = %x\n", gNP_Shutdown );
diff --git a/nsplugins/nspluginloader.cpp b/nsplugins/nspluginloader.cpp
index 2df8ed163..80634f72a 100644
--- a/nsplugins/nspluginloader.cpp
+++ b/nsplugins/nspluginloader.cpp
@@ -28,11 +28,11 @@
#include <tdeapplication.h>
-#include <kprocess.h>
+#include <tdeprocess.h>
#include <kdebug.h>
#include <tdeglobal.h>
#include <tdelocale.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeconfig.h>
#include <dcopclient.h>
#include <dcopstub.h>
@@ -201,8 +201,8 @@ NSPluginLoader::NSPluginLoader()
_filetype.setAutoDelete(true);
// trap dcop register events
- kapp->dcopClient()->setNotifications(true);
- TQObject::connect(kapp->dcopClient(),
+ tdeApp->dcopClient()->setNotifications(true);
+ TQObject::connect(tdeApp->dcopClient(),
TQ_SIGNAL(applicationRegistered(const TQCString&)),
this, TQ_SLOT(applicationRegistered(const TQCString&)));
@@ -272,7 +272,7 @@ void NSPluginLoader::scanPlugins()
continue;
}
- TQStringList desc = TQStringList::split(':', line, TRUE);
+ TQStringList desc = TQStringList::split(':', line, true);
TQString mime = desc[0].stripWhiteSpace();
TQStringList suffixes = TQStringList::split(',', desc[1].stripWhiteSpace());
if (!mime.isEmpty())
@@ -376,9 +376,9 @@ bool NSPluginLoader::loadViewer(const TQString &mimeType)
// wait for the process to run
int cnt = 0;
- while (!kapp->dcopClient()->isApplicationRegistered(_dcopid))
+ while (!tdeApp->dcopClient()->isApplicationRegistered(_dcopid))
{
//kapp->processEvents(); // would lead to recursive calls in tdehtml
#ifdef HAVE_USLEEP
usleep( 50*1000 );
#else
@@ -376,9 +376,9 @@ bool NSPluginLoader::loadViewer(const TQString &mimeType)
{
- //kapp->processEvents(); // would lead to recursive calls in tdehtml
+ //tdeApp->processEvents(); // would lead to recursive calls in tdehtml
#ifdef HAVE_USLEEP
usleep( 50*1000 );